/**
 * @typedef {import('interface-datastore').Datastore} Datastore
 * @typedef {import('interface-datastore').Pair} Pair
 * @typedef {import('interface-datastore').Batch} Batch
 * @typedef {import('interface-datastore').Query} Query
 * @typedef {import('interface-datastore').KeyQuery} KeyQuery
 * @typedef {import('interface-datastore').Options} QueryOptions
 */
/**
 * A datastore backed by leveldb.
 *
 * @implements {Datastore}
 */
export class LevelDatastore extends BaseDatastore implements Datastore {
    /**
     * @param {any} path
     * @param {Object} [opts]
     * @param {any} [opts.db] - level db reference
     * @param {boolean} [opts.createIfMissing]
     * @param {boolean} [opts.errorIfExists]
     * @param {string} [opts.prefix] - level-js option
     * @param {number} [opts.version] - level-js option
     * @param {number} [opts.cacheSize] - leveldown option
     * @param {number} [opts.writeBufferSize] - leveldown option
     * @param {number} [opts.blockSize] - leveldown option
     * @param {number} [opts.maxOpenFiles] - leveldown option
     * @param {number} [opts.blockRestartInterval] - leveldown option
     * @param {number} [opts.maxFileSize] - leveldown option
     */
    constructor(path: any, opts?: {
        db?: any;
        createIfMissing?: boolean | undefined;
        errorIfExists?: boolean | undefined;
        prefix?: string | undefined;
        version?: number | undefined;
        cacheSize?: number | undefined;
        writeBufferSize?: number | undefined;
        blockSize?: number | undefined;
        maxOpenFiles?: number | undefined;
        blockRestartInterval?: number | undefined;
        maxFileSize?: number | undefined;
    } | undefined);
    path: any;
    opts: {
        db?: any;
        createIfMissing?: boolean | undefined;
        errorIfExists?: boolean | undefined;
        prefix?: string | undefined;
        version?: number | undefined;
        cacheSize?: number | undefined;
        writeBufferSize?: number | undefined;
        blockSize?: number | undefined;
        maxOpenFiles?: number | undefined;
        blockRestartInterval?: number | undefined;
        maxFileSize?: number | undefined;
    } | undefined;
    database: any;
    _initDb(): Promise<any>;
    db: any;
    /**
     * @param {object} opts
     * @param {boolean} opts.values
     * @param {string} [opts.prefix]
     * @returns {AsyncIterable<Pair>}
     */
    _query(opts: {
        values: boolean;
        prefix?: string | undefined;
    }): AsyncIterable<Pair>;
}
export type LevelIterator = {
    next: (cb: (err: Error, key: string | Uint8Array | null, value: any) => void) => void;
    end: (cb: (err: Error) => void) => void;
};
export type Datastore = import('interface-datastore').Datastore;
export type Pair = import('interface-datastore').Pair;
export type Batch = import('interface-datastore').Batch;
export type Query = import('interface-datastore').Query;
export type KeyQuery = import('interface-datastore').KeyQuery;
export type QueryOptions = import('interface-datastore').Options;
import { BaseDatastore } from "datastore-core";
//# sourceMappingURL=index.d.ts.map